package jalview.api;

import java.util.Comparator;

/**
 * An interface that describes the settings configurable in the Feature Settings
 * dialog.
 * 
 * @author gmcarstairs
 *
 */
public interface FeatureSettingsI extends Comparator<String>
{
  // note Java 8 will allow default implementations of these methods in the
  // interface, simplifying instantiating classes

  /**
   * Answers true if the specified feature type is displayed
   * 
   * @param type
   * @return
   */
  boolean isFeatureDisplayed(String type);

  /**
   * Answers true if the specified feature group is displayed
   * 
   * @param group
   * @return
   */
  boolean isGroupDisplayed(String group);

  /**
   * Returns the colour (or graduated colour) for the feature type, or null if
   * not known
   * 
   * @param type
   * @return
   */
  FeatureColourI getFeatureColour(String type);

  /**
   * Returns the transparency value, from 0 (fully transparent) to 1 (fully
   * opaque)
   * 
   * @return
   */
  float getTransparency();

  /**
   * Returns -1 if feature1 'precedes' (is displayed on top of) feature 2, +1 if
   * feature2 is on top of feature1, or 0 if we don't care
   * 
   * @param feature1
   * @param feature2
   * @return
   */
  @Override
  int compare(String feature1, String feature2);

  /**
   * Answers true if features should be initially sorted so that features with a
   * shorter average length are displayed on top of those with a longer average
   * length
   * 
   * @return
   */
  boolean optimiseOrder();
}
